function activate_github(reponame; tag = nothing, sha = nothing, force = false)
    # Make sure that our .projects environment is kosher. 
    projdir = joinpath(pwd(), ".projects") 
    mkpath(projdir) 
    # For each case of inputs, end up with a concrete URL to download. 
    if sha != nothing 
        length(sha) >= 6 || throw(ArgumentError("SHA needs to be at least 6 characters."))
        tag == nothing || throw(ArgumentError("You can't give both a tag and an SHA hash."))
        tarprefix = sha   
    elseif tag != nothing # Given a version but no SHA. 
        tarprefix = tag
    else # Default to master if nothing is given. 
        tarprefix = "master"
    end 
    # Common objects for all cases. 
    repostr = split(reponame, "/")[2] 
    target = joinpath(projdir, "$repostr-$tarprefix") 
    # Branches of logic. 
    if isdir(target) && tarprefix != "master" && force == false # Static prefix that's already downloaded, no force. 
        Pkg.activate(target)
    else 
        # Make a temporary directory for our use. 
        tmpdir = tempdir()
        # Download the tarball to that directory. 
        tarurl = "https://github.com/$(reponame)/archive/$(tarprefix).tar.gz"
        tarpath = joinpath(tmpdir, "$repostr-$tarprefix.tar.gz")
        printstyled("Downloading ", bold=true, color=:light_green); println("$reponame-$tarprefix → $projdir")
        run(gen_download_cmd(tarurl, tarpath)) # Download the tarball. 
        # Unpack the tarball to that directory. 
        @suppress_out begin run(gen_unpack_cmd(tarpath, tmpdir)) end
        # Remove the tarball to avoid path conflict with the next steps. 
        rm(tarpath)
        # Find the path of the unpacked tarball (could be a full SHA)
        sourcedir = filter(object -> occursin("$repostr", object), readdir(tmpdir))[1] # There will only be one of these. 
        # Move to .projects
        mv("$tmpdir/$sourcedir", target, force = true) # Force will overwrite existing dir. 
        # Clean. 
        isdir(joinpath(tmpdir, sourcedir)) == false || rm(joinpath(tmpdir, sourcedir), recursive = true) # Important for logic. 
        # Instantiate and precompile.
        printstyled("Instantiating ", bold=true, color=:light_green); println(target)
        Pkg.activate(target)
        pkg"instantiate"
        pkg"precompile"
    end 
    tarprefix, target
end 

function copy_env(reponame, oldtag, newtag)
    repostr = split(reponame, "/")[2]
    projdir = joinpath(pwd(), ".projects")
    olddir = joinpath(projdir, "$repostr-$oldtag")
    newdir = joinpath(projdir, "$repostr-$newtag")
    cp(olddir, newdir, force = true)
end 